(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     70308,       1451]
NotebookOptionsPosition[     63861,       1323]
NotebookOutlinePosition[     65905,       1374]
CellTagsIndexPosition[     65577,       1362]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Local Markov Chain of Elementary Cellular Automata", "DemoTitle",
 CellChangeTimes->{
  3.35696210375764*^9, {3.390044768146248*^9, 
   3.3900447831478195`*^9}},ExpressionUUID->"0c42799c-ac15-4095-8688-\
6777199cdebe"],

Cell[CellGroupData[{

Cell["", "InitializationSection",ExpressionUUID->"8bea5ce5-b6ff-4796-b73f-92cc6fd9ca84"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"<<", "Combinatorica`"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"colors", "=", 
   RowBox[{"{", 
    RowBox[{"Green", ",", "Yellow", ",", "Purple", ",", "Red"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"randomInput", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Random", "[", "Integer", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"n", ",", " ", "1", ",", " ", "200"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BuildRule", "[", "prims_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "\t", 
      RowBox[{
       RowBox[{"tempPrims", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ",", "\n", "\t", 
       RowBox[{"tempRule", " ", "=", " ", 
        RowBox[{"{", "}"}]}]}], "}"}], ",", " ", "\n", "\t\t", 
     RowBox[{
      RowBox[{"tempPrims", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"IntegerDigits", "[", 
          RowBox[{
           RowBox[{"prims", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", "4", ",", " ", "2"}], 
          "]"}], ",", " ", 
         RowBox[{"IntegerDigits", "[", 
          RowBox[{
           RowBox[{"prims", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", " ", "4", ",", "2"}], 
          "]"}]}], "}"}]}], ";", "\n", "\t\t", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"tempRule", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{"tempRule", ",", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"tempPrims", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ")"}], "[", 
              RowBox[{"[", "n", "]"}], "]"}]}], "]"}], ",", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"tempPrims", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ")"}], "[", 
            RowBox[{"[", "n", "]"}], "]"}]}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"n", ",", " ", "1", ",", " ", 
          RowBox[{"Length", "[", 
           RowBox[{"tempPrims", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ";", 
      "\n", "\t\t", 
      RowBox[{"FromDigits", "[", 
       RowBox[{"tempRule", ",", " ", "4"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetCombinations", "[", "triad_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "\t", 
      RowBox[{"expTriad", " ", "=", " ", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"triad", ",", " ", "2", ",", " ", "3"}], "]"}]}], "}"}], ",", 
     "\n", "\t\t", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"m", ",", " ", "2", ",", " ", "2"}], "]"}], ")"}], "[", 
          RowBox[{"[", 
           RowBox[{"Table", "[", 
            RowBox[{"n", ",", " ", 
             RowBox[{"{", 
              RowBox[{"n", ",", " ", "1", ",", " ", "1"}], "}"}]}], "]"}], 
           "]"}], "]"}], ",", " ", 
         RowBox[{"Join", "[", 
          RowBox[{"expTriad", ",", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"IntegerDigits", "[", 
              RowBox[{"m", ",", " ", "2", ",", " ", "2"}], "]"}], ")"}], "[", 
            RowBox[{"[", 
             RowBox[{"Table", "[", 
              RowBox[{"n", ",", " ", 
               RowBox[{"{", 
                RowBox[{"n", ",", " ", 
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], ",", " ", 
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}]}], "}"}]}], "]"}], "]"}], "]"}]}],
           "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"m", ",", " ", "0", ",", " ", "3"}], "}"}]}], "]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetIndices", "[", "fivead_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "\t", 
      RowBox[{"fused", " ", "=", " ", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\n", "\t\t", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FromDigits", "[", 
        RowBox[{
         RowBox[{"fivead", "[", 
          RowBox[{"[", 
           RowBox[{"Table", "[", 
            RowBox[{"m", ",", " ", 
             RowBox[{"{", 
              RowBox[{"m", ",", " ", "n", ",", " ", 
               RowBox[{"n", " ", "+", " ", "2"}]}], "}"}]}], "]"}], "]"}], 
          "]"}], ",", " ", "2"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"n", ",", " ", "1", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetAdjacencyMatrix", "[", "rule_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "\t", 
      RowBox[{
       RowBox[{"expRule", " ", "=", " ", 
        RowBox[{"Reverse", "[", 
         RowBox[{"IntegerDigits", "[", 
          RowBox[{"rule", ",", " ", "2", ",", " ", "8"}], "]"}], "]"}]}], ",",
        "\n", "\t", "nextStates"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"nextStates", " ", "=", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"FromDigits", "[", 
              RowBox[{
               RowBox[{"expRule", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"GetIndices", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"GetCombinations", "[", "m", "]"}], ")"}], "[", 
                    RowBox[{"[", "n", "]"}], "]"}], "]"}], " ", "+", " ", 
                  "1"}], "]"}], "]"}], ",", " ", "2"}], "]"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"n", ",", " ", "1", ",", "4"}], "}"}]}], "]"}], "]"}], 
          ",", " ", 
          RowBox[{"{", 
           RowBox[{"m", ",", " ", "0", ",", " ", "7"}], "}"}]}], "]"}], " ", 
        "+", " ", "1"}]}], ";", "\n", "\t\t", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"FreeQ", "[", 
             RowBox[{
              RowBox[{"nextStates", "[", 
               RowBox[{"[", "n", "]"}], "]"}], ",", " ", "m"}], "]"}], ",", 
            " ", "Infinity", ",", " ", 
            RowBox[{"Length", "[", 
             RowBox[{"nextStates", "[", 
              RowBox[{"[", "n", "]"}], "]"}], "]"}]}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"m", ",", " ", "1", ",", " ", "8"}], "}"}]}], "]"}], ",", 
        " ", 
        RowBox[{"{", 
         RowBox[{"n", ",", " ", "1", ",", "8"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetWolframClass", "[", "rule_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\n", "\t", 
     RowBox[{"classes", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "0", ",", " ", "4", ",", " ", "8", ",", " ", "12", ",", " ", "13", 
          ",", " ", "32", ",", " ", "36", ",", " ", "40", ",", " ", "44", ",",
           " ", "64", ",", " ", "68", ",", " ", "69", ",", " ", "72", ",", 
          " ", "76", ",", " ", "77", ",", " ", "78", ",", "\n", "\t", "79", 
          ",", " ", "92", ",", " ", "93", ",", " ", "96", ",", " ", "100", 
          ",", " ", "104", ",", " ", "128", ",", " ", "132", ",", " ", "136", 
          ",", " ", "140", ",", " ", "141", ",", " ", "160", ",", " ", "164", 
          ",", " ", "168", ",", " ", "172", ",", "\n", "\t", "192", ",", " ", 
          "196", ",", " ", "197", ",", " ", "200", ",", " ", "202", ",", " ", 
          "203", ",", " ", "204", ",", " ", "205", ",", " ", "206", ",", " ", 
          "207", ",", " ", "216", ",", " ", "217", ",", " ", "218", ",", " ", 
          "219", ",", " ", "\n", "\t", "220", ",", " ", "221", ",", " ", 
          "222", ",", " ", "223", ",", " ", "224", ",", " ", "228", ",", " ", 
          "232", ",", " ", "233", ",", " ", "234", ",", " ", "235", ",", " ", 
          "236", ",", " ", "237", ",", " ", "238", ",", " ", "239", ",", " ", 
          "\n", "\t", "248", ",", " ", "249", ",", " ", "250", ",", " ", 
          "251", ",", " ", "252", ",", " ", "253", ",", " ", "254", ",", " ", 
          "255"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "1", ",", " ", "2", ",", " ", "3", ",", " ", "5", ",", " ", "6", ",",
           " ", "7", ",", " ", "9", ",", " ", "10", ",", " ", "11", ",", "\n",
           "\t", "14", ",", " ", "15", ",", " ", "16", ",", " ", "17", ",", 
          " ", "19", ",", " ", "20", ",", " ", "21", ",", " ", "23", ",", " ",
           "24", ",", " ", "25", ",", " ", "26", ",", " ", "27", ",", " ", 
          "28", ",", " ", "29", ",", " ", "31", ",", " ", "33", ",", " ", 
          "34", ",", " ", "35", ",", "\n", "\t", "37", ",", " ", "38", ",", 
          " ", "39", ",", " ", "41", ",", " ", "42", ",", " ", "43", ",", " ",
           "46", ",", " ", "47", ",", " ", "48", ",", " ", "49", ",", " ", 
          "50", ",", " ", "51", ",", " ", "52", ",", " ", "53", ",", " ", 
          "55", ",", " ", "56", ",", " ", "57", ",", " ", "58", ",", "\n", 
          "\t", "59", ",", " ", "61", ",", " ", "62", ",", " ", "63", ",", 
          " ", "65", ",", " ", "66", ",", " ", "67", ",", " ", "70", ",", " ",
           "71", ",", " ", "73", ",", " ", "74", ",", " ", "80", ",", " ", 
          "81", ",", " ", "82", ",", " ", "83", ",", " ", "84", ",", " ", 
          "85", ",", " ", "87", ",", "\n", "\t", "88", ",", " ", "91", ",", 
          " ", "94", ",", " ", "95", ",", " ", "97", ",", " ", "98", ",", " ",
           "99", ",", " ", "103", ",", " ", "107", ",", " ", "108", ",", " ", 
          "109", ",", " ", "111", ",", " ", "112", ",", " ", "113", ",", " ", 
          "114", ",", " ", "115", ",", "\n", "\t", "116", ",", " ", "117", 
          ",", " ", "118", ",", " ", "119", ",", " ", "121", ",", " ", "123", 
          ",", " ", "125", ",", " ", "127", ",", " ", "130", ",", " ", "131", 
          ",", " ", "133", ",", " ", "134", ",", " ", "138", ",", " ", "139", 
          ",", " ", "\n", "\t", "142", ",", " ", "143", ",", " ", "144", ",", 
          " ", "145", ",", " ", "148", ",", " ", "152", ",", " ", "154", ",", 
          " ", "155", ",", " ", "156", ",", " ", "157", ",", " ", "158", ",", 
          " ", "159", ",", " ", "162", ",", " ", "163", ",", " ", "\n", "\t", 
          "166", ",", " ", "167", ",", " ", "170", ",", " ", "171", ",", " ", 
          "173", ",", " ", "174", ",", " ", "175", ",", " ", "176", ",", " ", 
          "177", ",", " ", "178", ",", " ", "179", ",", " ", "180", ",", " ", 
          "181", ",", " ", "184", ",", " ", "\n", "\t", "185", ",", " ", 
          "186", ",", " ", "187", ",", " ", "188", ",", " ", "189", ",", " ", 
          "190", ",", " ", "191", ",", " ", "194", ",", " ", "198", ",", " ", 
          "199", ",", " ", "201", ",", " ", "208", ",", " ", "209", ",", " ", 
          "210", ",", " ", "\n", "\t", "211", ",", " ", "212", ",", " ", 
          "213", ",", " ", "214", ",", " ", "215", ",", " ", "226", ",", " ", 
          "227", ",", " ", "229", ",", " ", "230", ",", " ", "231", ",", " ", 
          "240", ",", " ", "241", ",", " ", "242", ",", " ", "243", ",", " ", 
          "\n", "\t", "244", ",", " ", "245", ",", " ", "246", ",", " ", 
          "247"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "18", ",", " ", "22", ",", " ", "30", ",", " ", "45", ",", " ", "60",
           ",", " ", "75", ",", " ", "86", ",", " ", "89", ",", " ", "90", 
          ",", " ", "101", ",", " ", "102", ",", " ", "105", ",", " ", "\n", 
          "\t", "106", ",", " ", "120", ",", " ", "122", ",", " ", "126", ",",
           " ", "129", ",", " ", "135", ",", " ", "146", ",", " ", "149", ",",
           " ", "150", ",", " ", "151", ",", " ", "153", ",", " ", "161", ",",
           " ", "165", ",", " ", "169", ",", "\n", "\t", "182", ",", " ", 
          "183", ",", " ", "195", ",", " ", "225"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "54", ",", " ", "110", ",", " ", "124", ",", " ", "137", ",", "147", 
          ",", " ", "193"}], "}"}]}], "}"}]}], "}"}], ",", "\n", "\t\t", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"classes", "[", 
           RowBox[{"[", "n", "]"}], "]"}], ",", " ", "rule"}], "]"}], ",", 
        " ", 
        RowBox[{"Return", "[", "n", "]"}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "1", ",", " ", 
        RowBox[{"Length", "[", "classes", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.3900389569802017`*^9, 3.390038992611437*^9}, {
   3.3900439542359023`*^9, 3.390043956539214*^9}, {3.3900499643279905`*^9, 
   3.3900499848975677`*^9}, {3.3900543848343663`*^9, 
   3.3900544098202944`*^9}, {3.3900545007710752`*^9, 
   3.3900546076848097`*^9}, {3.3900546524992495`*^9, 3.390054667610979*^9}, {
   3.390054756158304*^9, 3.3900547605345964`*^9}, {3.390054952140112*^9, 
   3.3900549603419056`*^9}, {3.3900550254555345`*^9, 3.3900552211369104`*^9}},
 CellLabel->"In[1]:=",
 CellID->150388285,ExpressionUUID->"86049c62-d708-41ab-be6c-cf4782842806"],

Cell[BoxData[
 TemplateBox[{
  "General","compat",
   "\"Combinatorica Graph and Permutations functionality has been superseded \
by preloaded functionality. The package now being loaded may conflict with \
this. Please see the Compatibility Guide for details.\"",2,1,33,
   29443196315561340393,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.748879498951161*^9},
 CellLabel->"During evaluation of In[1]:=",
 CellID->1261811154,ExpressionUUID->"ee156408-7e7f-4850-9863-4822cea430dd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateSection",ExpressionUUID->"5400cb6b-d54b-4d90-be96-6847d5c12c5c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ShowGraph", "[", 
         RowBox[{
          RowBox[{"SpringEmbedding", "[", 
           RowBox[{
            RowBox[{"FromAdjacencyMatrix", "[", 
             RowBox[{
              RowBox[{"GetAdjacencyMatrix", "[", 
               RowBox[{"BuildRule", "[", 
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["p", "0"], ",", 
                  SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}], ",", 
              "EdgeWeight", ",", 
              RowBox[{"Type", "\[Rule]", "Directed"}]}], "]"}], ",", "100", 
            ",", "0.15`"}], "]"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"BuildRule", "[", 
              RowBox[{"{", 
               RowBox[{
                SubscriptBox["p", "0"], ",", 
                SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}], " ", 
            RowBox[{"Text", "[", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["p", "0"], ",", 
               SubscriptBox["p", "1"]}], "}"}], "]"}]}]}], " ", ",", 
          RowBox[{"VertexLabel", "\[Rule]", "True"}], ",", 
          RowBox[{"EdgeColor", "\[Rule]", 
           RowBox[{"colors", "[", 
            RowBox[{"[", 
             RowBox[{"GetWolframClass", "[", 
              RowBox[{"BuildRule", "[", 
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["p", "0"], ",", 
                 SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}], "]"}], 
            "]"}]}]}], "]"}], ",", 
        RowBox[{"ArrayPlot", "[", 
         RowBox[{
          RowBox[{"CellularAutomaton", "[", 
           RowBox[{
            RowBox[{"BuildRule", "[", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["p", "0"], ",", 
               SubscriptBox["p", "1"]}], "}"}], "]"}], ",", "randomInput", 
            ",", "100"}], "]"}], ",", 
          RowBox[{"PixelConstrained", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"BuildRule", "[", 
              RowBox[{"{", 
               RowBox[{
                SubscriptBox["p", "0"], ",", 
                SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}], " ", 
            RowBox[{"Text", "[", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["p", "0"], ",", 
               SubscriptBox["p", "1"]}], "}"}], "]"}]}]}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GraphPlot", "[", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"GetAdjacencyMatrix", "[", 
            RowBox[{"BuildRule", "[", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["p", "0"], ",", 
               SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}]}], ",", 
          RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
          RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "256"}], ",", 
          RowBox[{"SelfLoopStyle", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"MatrixForm", "[", 
         RowBox[{"1", "/", 
          RowBox[{"GetAdjacencyMatrix", "[", 
           RowBox[{"BuildRule", "[", 
            RowBox[{"{", 
             RowBox[{
              SubscriptBox["p", "0"], ",", 
              SubscriptBox["p", "1"]}], "}"}], "]"}], "]"}]}], "]"}]}], 
       "}"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["p", "0"], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "8", ",", "4", ",", "2", ",", "1", ",", "9", ",", "6", ",", 
       "3", ",", "5", ",", "12", ",", "10", ",", "14", ",", "11", ",", " ", 
       "13", ",", "7", ",", "15"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "Slider"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["p", "1"], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "15", ",", "14", ",", "13", ",", "11", ",", "7", ",", "6", ",", "9", 
       ",", "3", ",", "5", ",", "12", ",", "10", ",", "8", ",", "2", ",", "4",
        ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "VerticalSlider"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "}"}], ",", " ", 
   RowBox[{
   "FrameLabel", "\[Rule]", 
    "\"\<Local Markov Chain (SpringEmbedding) - Evolution from Random Input \
\\nGraphPlot - Probability Transition Matrix\>\""}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Blue", ",", "Medium"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.3900390196603312`*^9, 3.390039035743458*^9}, {
   3.3900391038113346`*^9, 3.39003910530348*^9}, {3.3900393482127666`*^9, 
   3.390039383884059*^9}, {3.3900395292831326`*^9, 3.3900396036300383`*^9}, 
   3.390039713568122*^9, {3.3900412001757584`*^9, 3.3900412275150704`*^9}, {
   3.3900414165869427`*^9, 3.390041417017562*^9}, {3.3900422869084034`*^9, 
   3.390042335868805*^9}, {3.390042384939365*^9, 3.390042394513131*^9}, {
   3.3900424866556253`*^9, 3.390042487096259*^9}, {3.3900425179205823`*^9, 
   3.390042571077018*^9}, {3.3900427398997726`*^9, 3.3900427599586163`*^9}, {
   3.390042795139203*^9, 3.3900428378305902`*^9}, {3.3900429421806383`*^9, 
   3.3900429429217043`*^9}, {3.3900429833698654`*^9, 
   3.3900429837704415`*^9}, {3.390043194613619*^9, 3.3900432162046657`*^9}, {
   3.390043254850235*^9, 3.390043304601774*^9}, {3.390043756121027*^9, 
   3.3900437595259233`*^9}, {3.3900438051715584`*^9, 
   3.3900438634353375`*^9}, {3.3900439856811185`*^9, 3.390044018818768*^9}, {
   3.390045261055016*^9, 3.390045270789013*^9}, {3.3900453814681616`*^9, 
   3.390045398182195*^9}, {3.390045430849168*^9, 3.3900454721986256`*^9}, {
   3.390045553305251*^9, 3.3900455593539486`*^9}, {3.390048667613406*^9, 
   3.3900486680640545`*^9}, {3.3900487283507423`*^9, 
   3.3900487286912317`*^9}, {3.390048795156805*^9, 3.390048823757931*^9}, {
   3.3900492908996477`*^9, 3.390049383612963*^9}, {3.390049442487621*^9, 
   3.3900494584205313`*^9}, 3.3900495249962626`*^9, 3.3900499917173743`*^9, {
   3.3900544248118515`*^9, 3.3900544556762323`*^9}, {3.390054822503704*^9, 
   3.3900548228041363`*^9}, {3.390132584468091*^9, 3.3901326037558255`*^9}, {
   3.390132670581917*^9, 3.39013267145317*^9}, {3.3902103893932743`*^9, 
   3.3902103950814533`*^9}, {3.3902109945734806`*^9, 
   3.3902110199399557`*^9}, {3.390211915447633*^9, 3.3902119553550167`*^9}, {
   3.3902120289207993`*^9, 3.3902120373228807`*^9}, {3.390212069749508*^9, 
   3.390212080394815*^9}, {3.3902121822813206`*^9, 3.3902122405150566`*^9}, {
   3.3902123417906837`*^9, 3.3902123446848454`*^9}, {3.3902124339431925`*^9, 
   3.39021243682734*^9}, {3.3902124781868114`*^9, 3.390212540406279*^9}, {
   3.3902127893842916`*^9, 3.3902127954830613`*^9}, {3.390213184592573*^9, 
   3.3902131852435093`*^9}, {3.390213443705159*^9, 3.3902134442859945`*^9}, {
   3.3902135037014294`*^9, 3.390213507897463*^9}, {3.39021363320765*^9, 
   3.390213676449829*^9}, {3.390213782492311*^9, 3.3902138228203*^9}, {
   3.390213853163932*^9, 3.390213891869588*^9}, {3.390213969170741*^9, 
   3.3902139752594967`*^9}, {3.390214122330975*^9, 3.390214122711522*^9}, {
   3.390219433898634*^9, 3.3902194525654755`*^9}, {3.390909955680179*^9, 
   3.3909100228067026`*^9}, 3.3909101866923585`*^9, {3.3909102233450623`*^9, 
   3.390910224606877*^9}, {3.390910260708789*^9, 
   3.3909102872870064`*^9}},ExpressionUUID->"087507c8-921f-464e-87be-\
3f5a1b3ae566"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 14, $CellContext`$14$$ = 2, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {481., {210.3544921875, 215.6455078125}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{570., {275., 281.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->8553930,ExpressionUUID->"74fd93aa-368c-4cb1-b7bc-d50ecb603b23"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection",ExpressionUUID->"92a91f18-696f-40e3-a70c-b925d3b5536d"],

Cell["Local Markov Chain of Elementary Cellular Automata", "ManipulateCaption",
 CellChangeTimes->{
  3.35696210375764*^9, {3.390044548330168*^9, 3.3900445599468718`*^9}, {
   3.3900448108776927`*^9, 3.390044811228197*^9}, {3.390053435098714*^9, 
   3.3900534537655554`*^9}},ExpressionUUID->"da48c37f-79ee-4ced-825d-\
7d82723d0466"],

Cell[TextData[{
 "Cellular Automata is defined by a mapping from a cell and its neighborhood \
to the next value of that cell. If we match the value of a cell and its \
neighborhood to a state we can define the next state of that range given that \
we know the values of the cells to the right and left of the range. Since \
these values would depend on the actual input and evolution of the CA, we \
assume that the values of these cells to the left and right and equally \
likely. With this information we create a Local Markov Chain for a given \
range of a cell and its neighborhood. This demostration shows the LMC for the \
Elementary Cellular Automata.  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "0"], "and", " ", 
    SubscriptBox["p", "1"]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "06b8bdad-1bd2-4a2f-b53a-dd4a74a0f8bc"],
 " are primitives for the rule."
}], "ManipulateCaption",
 CellChangeTimes->{
  3.35696210375764*^9, {3.3900534576311135`*^9, 3.3900535271610928`*^9}, {
   3.3900535922246494`*^9, 3.390053834693302*^9}},
 CellID->179281611,ExpressionUUID->"f4785b54-e131-4883-b9f0-d3d4134d83de"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection",ExpressionUUID->"1efd7e8b-bbdc-4bba-9124-88d220f99bb5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 6, $CellContext`$14$$ = 3, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {481., {183.3544921875, 188.6455078125}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{570., {248., 254.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->74067128,ExpressionUUID->"53f6f66e-7b0f-4ac4-aca8-7a82d7ca0253"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection",ExpressionUUID->"3ec677e4-e566-44f7-82f1-4dc9c4d36c3b"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 8, $CellContext`$14$$ = 9, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {464., {207.5, 212.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{553., {272., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->527918330,ExpressionUUID->"988de7e6-8d7d-493e-8c2e-0788ab948d41"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 4, $CellContext`$14$$ = 8, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {464., {192.5, 197.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{553., {257., 263.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->24205412,ExpressionUUID->"68379a5d-d130-4e22-8211-2ffd900d7bf2"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 6, $CellContext`$14$$ = 5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {464., {201.5, 206.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{553., {266., 272.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->393680344,ExpressionUUID->"695f045b-7a91-4c74-8b80-b213308ff5cb"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`$13$$ = 10, $CellContext`$14$$ = 7, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`$13$$], 6, "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0,
       8, 4, 2, 1, 9, 6, 3, 5, 12, 10, 14, 11, 13, 7, 15}}, {{
       Hold[$CellContext`$14$$], 3, "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {
      15, 14, 13, 11, 7, 6, 9, 3, 5, 12, 10, 8, 2, 4, 1, 0}}}, 
    Typeset`size$$ = {464., {227.5, 232.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`$13$9716$$ = 0, $CellContext`$14$9717$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`$13$$ = 6, $CellContext`$14$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`$13$$, $CellContext`$13$9716$$, 0], 
        Hold[$CellContext`$14$$, $CellContext`$14$9717$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> TableForm[{{
          Combinatorica`ShowGraph[
           Combinatorica`SpringEmbedding[
            Combinatorica`FromAdjacencyMatrix[
             $CellContext`GetAdjacencyMatrix[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]], Combinatorica`EdgeWeight, Combinatorica`Type -> 
             Combinatorica`Directed], 100, 0.15], PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}], 
           Combinatorica`VertexLabel -> True, Combinatorica`EdgeColor -> 
           Part[$CellContext`colors, 
             $CellContext`GetWolframClass[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]], 
          ArrayPlot[
           CellularAutomaton[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}], \
$CellContext`randomInput, 100], PixelConstrained -> True, PlotLabel -> Text[
              $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]] Text[{$CellContext`$13$$, $CellContext`$14$$}]]}, {
          GraphPlot[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, $CellContext`$14$$}]],
            DirectedEdges -> True, VertexLabeling -> True, ImageSize -> 256, 
           SelfLoopStyle -> All], 
          MatrixForm[1/$CellContext`GetAdjacencyMatrix[
            $CellContext`BuildRule[{$CellContext`$13$$, \
$CellContext`$14$$}]]]}}], 
      "Specifications" :> {{{$CellContext`$13$$, 6, 
          "\!\(\*TagBox[\(p\_0\), HoldForm]\)"}, {0, 8, 4, 2, 1, 9, 6, 3, 5, 
         12, 10, 14, 11, 13, 7, 15}, ControlType -> 
         Slider}, {{$CellContext`$14$$, 3, 
          "\!\(\*TagBox[\(p\_1\), HoldForm]\)"}, {15, 14, 13, 11, 7, 6, 9, 3, 
         5, 12, 10, 8, 2, 4, 1, 0}, ControlType -> VerticalSlider, 
         ControlPlacement -> Left}}, 
      "Options" :> {
       FrameLabel -> 
        "Local Markov Chain (SpringEmbedding) - Evolution from Random Input \n\
GraphPlot - Probability Transition Matrix", LabelStyle -> Directive[
          RGBColor[0, 0, 1], Medium]}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{553., {292., 298.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.390045272401331*^9, 3.390045403710144*^9, {
   3.3900454425359726`*^9, 3.3900454736807566`*^9}, 3.390048668855192*^9, {
   3.3900487301533346`*^9, 3.390048762509861*^9}, {3.390048798621787*^9, 
   3.390048825650653*^9}, {3.3900488620529966`*^9, 3.3900488656681952`*^9}, {
   3.3900493015449553`*^9, 3.390049385505685*^9}, 3.3900494607639008`*^9, 
   3.3900495266987104`*^9, 3.390049693458499*^9, 3.390050000650219*^9, {
   3.3900547996208*^9, 3.3900548279415236`*^9}, 3.3900549703062334`*^9, 
   3.3900552343559184`*^9, 3.3901326081120896`*^9, 3.39013267295533*^9, 
   3.3902103975349817`*^9, {3.3902110058897524`*^9, 3.390211022313369*^9}, {
   3.390211930309002*^9, 3.3902119567269897`*^9}, 3.3902120385947094`*^9, 
   3.390212082798271*^9, {3.3902121851654677`*^9, 3.390212199996794*^9}, {
   3.3902122368497863`*^9, 3.3902122425680084`*^9}, 3.3902123460868616`*^9, 
   3.3902124390905943`*^9, {3.390212496813596*^9, 3.3902125073888025`*^9}, 
   3.390212542429188*^9, 3.390212796374343*^9, 3.3902131870861588`*^9, 
   3.390213446168701*^9, 3.390213509569868*^9, {3.390213663871743*^9, 
   3.3902136800850563`*^9}, {3.390213797543954*^9, 3.390213825524188*^9}, {
   3.3902138558077335`*^9, 3.390213896295953*^9}, 3.390213976060649*^9, 
   3.390214124684359*^9, 3.3902142223447876`*^9, {3.390219444253524*^9, 
   3.3902194550690756`*^9}, 3.3902957649202957`*^9, 3.3902961460182877`*^9, 
   3.390909840093974*^9, 3.390909959655896*^9, 3.390909994175533*^9, 
   3.390910188755325*^9, 3.3909102258486624`*^9, {3.3909102659062624`*^9, 
   3.3909102892398143`*^9}},
 CellID->155733211,ExpressionUUID->"26bdf201-cc7a-4b4a-8449-b4216884ed29"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "DetailsSection",ExpressionUUID->"04ca38f3-2196-42ba-905b-895264d12b33"],

Cell["\<\
The snapshots shown for cellular automata of each class according to the \
Wolfram Classification: Class 1, Class 2, Class 3, and Class 4.\
\>", "DetailNotes",
 CellChangeTimes->{
  3.35696210375764*^9, {3.390054206417816*^9, 3.3900542827976446`*^9}},
 CellID->34435196,ExpressionUUID->"c66fd2f6-3de4-408f-88d4-aeda8e58af76"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection",ExpressionUUID->"6c346fba-0a9c-4c61-84e3-c5bcad375fde"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"932be86a-5519-4bb1-822f-5463ee58a6a9"]}],
  "Hold down the Alt key while moving the sliders for fine adjustment. \n\
Holding Ctrl and/or Shift at the same time as Alt increases the precision of \
the adjustment.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"8e901b7f-82cd-4253-940e-b4fe69d74b58"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "fc4dc6a2-a4c7-4aa5-b2f5-8bf94621e291"]}],
  "Create a locator by holding down the Alt key and clicking within the  \n\
graphic.\nDelete a locator by clicking it while holding down the Alt key.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"b56c498f-1c12-4afc-81f2-\
261be965d182"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"562ab190-d389-41e9-8a43-f114708c7fb5"]}],
  "Drag the locators inside this Demonstration to change its settings.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"087810dc-d2e3-4a31-9866-a494b37d818b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "73b654c9-68cf-4009-9830-574ee599b24b"]}],
  "Drag a 3D graphic to rotate it. Starting the drag near the center tumbles \
the graphic; \nstarting near a corner turns it parallel to the plane of the \
screen. Hold down Ctrl \n(or Cmd on Mac) and drag up and down to zoom.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"4107f007-9214-4e8d-931a-95daf7ba81d2"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "7418ccb1-958b-4e92-8908-dea6c1b9e01b"]}],
  "Make an animation by clicking the button next to a slider and the play \
button \nthat appears underneath it, or animate all the sliders by selecting \
Autorun \nfrom the menu.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"8aaf5768-16b6-4fc8-87cb-b601e03a6265"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "a0a9bfa1-eee2-47c3-b496-07a136f374a2"]}],
  "Instead of using the sliders and other controls, use a gamepad connected \
to your computer.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"283c682d-2dae-4161-b747-3f215b8dff33"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"ffe75646-bf86-48c8-b8bb-1d3562a53f70"]}],
  "Drag the lower\[Hyphen]right corner of an image to resize it.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"b71793e1-4c4d-4d73-ae76-3fe384e04a39"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "9ebb8d69-4e9a-4bb6-b48c-3ff54376b612"]}],
  "Create an animation by adding bookmarks and then selecting Animate \
Bookmarks from the menu.",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"b4f7122e-9914-4ade-81a2-914f3ab6e46f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SearchTermsSection",ExpressionUUID->"13d4bc2d-85d3-47c8-928f-67eb551fdf7c"],

Cell["Elementary Cellular Automata", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.390053948366757*^9, 3.390053960033533*^9}},
 CellID->230174162,ExpressionUUID->"ec612c67-9992-4044-9838-116a4b8840e9"],

Cell["Local Markov Chain", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.3900539641093936`*^9, 3.3900539678447647`*^9}},
 CellID->628994560,ExpressionUUID->"a6851913-6aab-4ce8-bc85-e6c7876cd3c7"],

Cell["Primitives", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.39005396951717*^9, 3.3900539708590994`*^9}},
 CellID->27757533,ExpressionUUID->"93504cf0-b732-453a-a2d6-03b9c239e4f8"]
}, Open  ]],

Cell["", "RelatedLinksSection",ExpressionUUID->"163abf58-a1bc-48ab-b538-991fdfbb2999"],

Cell[CellGroupData[{

Cell["", "AuthorSection",ExpressionUUID->"aa480bfe-4e7c-4987-9074-49ca90442c04"],

Cell["Contributed by: Rodrigo A. Obando", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.390044418373299*^9, 
   3.3900444209369855`*^9}},ExpressionUUID->"bf6f2a16-21f8-4f6c-93dd-\
521a3d2dc3e8"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{682, 933},
WindowMargins->{{45, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SliderZoom"->{
  Cell[59082, 1185, 468, 11, 22, "ControlSuggestions",ExpressionUUID->"8e901b7f-82cd-4253-940e-b4fe69d74b58",
   CellTags->"SliderZoom"]},
 "CreateAndDeleteLocators"->{
  Cell[59553, 1198, 484, 12, 22, "ControlSuggestions",ExpressionUUID->"b56c498f-1c12-4afc-81f2-261be965d182",
   CellTags->"CreateAndDeleteLocators"]},
 "DragLocators"->{
  Cell[60040, 1212, 373, 9, 22, "ControlSuggestions",ExpressionUUID->"087810dc-d2e3-4a31-9866-a494b37d818b",
   CellTags->"DragLocators"]},
 "RotateAndZoomIn3D"->{
  Cell[60416, 1223, 548, 12, 22, "ControlSuggestions",ExpressionUUID->"4107f007-9214-4e8d-931a-95daf7ba81d2",
   CellTags->"RotateAndZoomIn3D"]},
 "AutomaticAnimation"->{
  Cell[60967, 1237, 499, 12, 22, "ControlSuggestions",ExpressionUUID->"8aaf5768-16b6-4fc8-87cb-b601e03a6265",
   CellTags->"AutomaticAnimation"]},
 "GamepadControls"->{
  Cell[61469, 1251, 409, 11, 22, "ControlSuggestions",ExpressionUUID->"283c682d-2dae-4161-b747-3f215b8dff33",
   CellTags->"GamepadControls"]},
 "ResizeImages"->{
  Cell[61881, 1264, 367, 9, 22, "ControlSuggestions",ExpressionUUID->"b71793e1-4c4d-4d73-ae76-3fe384e04a39",
   CellTags->"ResizeImages"]},
 "BookmarkAnimation"->{
  Cell[62251, 1275, 414, 11, 22, "ControlSuggestions",ExpressionUUID->"b4f7122e-9914-4ade-81a2-914f3ab6e46f",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SliderZoom", 64237, 1335},
 {"CreateAndDeleteLocators", 64406, 1338},
 {"DragLocators", 64577, 1341},
 {"RotateAndZoomIn3D", 64741, 1344},
 {"AutomaticAnimation", 64912, 1347},
 {"GamepadControls", 65081, 1350},
 {"ResizeImages", 65244, 1353},
 {"BookmarkAnimation", 65408, 1356}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 224, 4, 108, "DemoTitle",ExpressionUUID->"0c42799c-ac15-4095-8688-6777199cdebe"],
Cell[CellGroupData[{
Cell[816, 30, 88, 0, 301, "InitializationSection",ExpressionUUID->"8bea5ce5-b6ff-4796-b73f-92cc6fd9ca84"],
Cell[CellGroupData[{
Cell[929, 34, 13639, 296, 997, "Input",ExpressionUUID->"86049c62-d708-41ab-be6c-cf4782842806",
 CellID->150388285],
Cell[14571, 332, 508, 10, 57, "Message",ExpressionUUID->"ee156408-7e7f-4850-9863-4822cea430dd",
 CellID->1261811154]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15128, 348, 84, 0, 247, "ManipulateSection",ExpressionUUID->"5400cb6b-d54b-4d90-be96-6847d5c12c5c"],
Cell[CellGroupData[{
Cell[15237, 352, 7816, 167, 389, "Input",ExpressionUUID->"087507c8-921f-464e-87be-3f5a1b3ae566"],
Cell[23056, 521, 5605, 98, 568, "Output",ExpressionUUID->"74fd93aa-368c-4cb1-b7bc-d50ecb603b23",
 CellID->8553930]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28710, 625, 91, 0, 181, "ManipulateCaptionSection",ExpressionUUID->"92a91f18-696f-40e3-a70c-b925d3b5536d"],
Cell[28804, 627, 332, 5, 23, "ManipulateCaption",ExpressionUUID->"da48c37f-79ee-4ced-825d-7d82723d0466"],
Cell[29139, 634, 1143, 21, 135, "ManipulateCaption",ExpressionUUID->"f4785b54-e131-4883-b9f0-d3d4134d83de",
 CellID->179281611]
}, Open  ]],
Cell[CellGroupData[{
Cell[30319, 660, 83, 0, 179, "ThumbnailSection",ExpressionUUID->"1efd7e8b-bbdc-4bba-9124-88d220f99bb5"],
Cell[30405, 662, 5605, 98, 514, "Output",ExpressionUUID->"53f6f66e-7b0f-4ac4-aca8-7a82d7ca0253",
 CellID->74067128]
}, Open  ]],
Cell[CellGroupData[{
Cell[36047, 765, 83, 0, 138, "SnapshotsSection",ExpressionUUID->"3ec677e4-e566-44f7-82f1-4dc9c4d36c3b"],
Cell[36133, 767, 5588, 98, 559, "Output",ExpressionUUID->"988de7e6-8d7d-493e-8c2e-0788ab948d41",
 CellID->527918330],
Cell[41724, 867, 5587, 98, 529, "Output",ExpressionUUID->"68379a5d-d130-4e22-8211-2ffd900d7bf2",
 CellID->24205412],
Cell[47314, 967, 5588, 98, 547, "Output",ExpressionUUID->"695f045b-7a91-4c74-8b80-b213308ff5cb",
 CellID->393680344],
Cell[52905, 1067, 5589, 98, 599, "Output",ExpressionUUID->"26bdf201-cc7a-4b4a-8449-b4216884ed29",
 CellID->155733211]
}, Open  ]],
Cell[CellGroupData[{
Cell[58531, 1170, 81, 0, 232, "DetailsSection",ExpressionUUID->"04ca38f3-2196-42ba-905b-895264d12b33"],
Cell[58615, 1172, 335, 6, 37, "DetailNotes",ExpressionUUID->"c66fd2f6-3de4-408f-88d4-aeda8e58af76",
 CellID->34435196]
}, Open  ]],
Cell[CellGroupData[{
Cell[58987, 1183, 92, 0, 120, "ControlSuggestionsSection",ExpressionUUID->"6c346fba-0a9c-4c61-84e3-c5bcad375fde"],
Cell[59082, 1185, 468, 11, 22, "ControlSuggestions",ExpressionUUID->"8e901b7f-82cd-4253-940e-b4fe69d74b58",
 CellTags->"SliderZoom"],
Cell[59553, 1198, 484, 12, 22, "ControlSuggestions",ExpressionUUID->"b56c498f-1c12-4afc-81f2-261be965d182",
 CellTags->"CreateAndDeleteLocators"],
Cell[60040, 1212, 373, 9, 22, "ControlSuggestions",ExpressionUUID->"087810dc-d2e3-4a31-9866-a494b37d818b",
 CellTags->"DragLocators"],
Cell[60416, 1223, 548, 12, 22, "ControlSuggestions",ExpressionUUID->"4107f007-9214-4e8d-931a-95daf7ba81d2",
 CellTags->"RotateAndZoomIn3D"],
Cell[60967, 1237, 499, 12, 22, "ControlSuggestions",ExpressionUUID->"8aaf5768-16b6-4fc8-87cb-b601e03a6265",
 CellTags->"AutomaticAnimation"],
Cell[61469, 1251, 409, 11, 22, "ControlSuggestions",ExpressionUUID->"283c682d-2dae-4161-b747-3f215b8dff33",
 CellTags->"GamepadControls"],
Cell[61881, 1264, 367, 9, 22, "ControlSuggestions",ExpressionUUID->"b71793e1-4c4d-4d73-ae76-3fe384e04a39",
 CellTags->"ResizeImages"],
Cell[62251, 1275, 414, 11, 22, "ControlSuggestions",ExpressionUUID->"b4f7122e-9914-4ade-81a2-914f3ab6e46f",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62702, 1291, 85, 0, 152, "SearchTermsSection",ExpressionUUID->"13d4bc2d-85d3-47c8-928f-67eb551fdf7c"],
Cell[62790, 1293, 216, 3, 22, "SearchTerms",ExpressionUUID->"ec612c67-9992-4044-9838-116a4b8840e9",
 CellID->230174162],
Cell[63009, 1298, 210, 3, 22, "SearchTerms",ExpressionUUID->"a6851913-6aab-4ce8-bc85-e6c7876cd3c7",
 CellID->628994560],
Cell[63222, 1303, 198, 3, 22, "SearchTerms",ExpressionUUID->"93504cf0-b732-453a-a2d6-03b9c239e4f8",
 CellID->27757533]
}, Open  ]],
Cell[63435, 1309, 86, 0, 138, "RelatedLinksSection",ExpressionUUID->"163abf58-a1bc-48ab-b538-991fdfbb2999"],
Cell[CellGroupData[{
Cell[63546, 1313, 80, 0, 124, "AuthorSection",ExpressionUUID->"aa480bfe-4e7c-4987-9074-49ca90442c04"],
Cell[63629, 1315, 204, 4, 22, "Author",ExpressionUUID->"bf6f2a16-21f8-4f6c-93dd-521a3d2dc3e8"]
}, Open  ]]
}, Open  ]]
}
]
*)

